@@ -132,10 +132,7 @@ class ScanRunner(object):
             container = client.containers.run(docker_image, command_line, volumes=volumes, detach=True, tty=False, stdout=True, stderr=True)
             container.wait()
         except Exception as de:
-            if sys.version_info < (3, 0):
-                raise DockerError('Failed to run docker image: ' + str(de))
-            else:
-                raise DockerError('Failed to run docker image: ' + str(de)) from de
+            raise DockerError('Failed to run docker image: ' + str(de))
 
         # write stdout and stderr output
         try:
