@@ -35,6 +35,7 @@ class Utils(object):
 	last_time_docker_login = 0
 	minutes25 = 60*25
 	cloc_file = None
+	min_docker_version = 18.03
 
 	@classmethod
 	def get_retryable_http(cls):
@@ -64,6 +65,22 @@ class Utils(object):
 			print('No running docker client found, please ensure the docker client is running.')
 			print(str(e))
 			exit(-1)
+	
+	@classmethod
+	def assert_docker_version(cls):
+		try:
+			client = docker.from_env()
+			version_info = client.version()
+			version_parts = version_info['Version'].split('.')
+			version_number = float(version_parts[0] + '.' + version_parts[1])
+
+			if version_number < cls.min_docker_version:
+				print("We don't support the docker version you're running, please upgrade to " + str(cls.min_docker_version) + " or higher.")
+				exit(-1)
+		except Exception as e:
+			print('Error occurred when checking the docker version, please contact support.')
+			print(str(e))
+			exit(-1)
 
 	@classmethod
 	def docker_login(cls, scan_info):
@@ -79,20 +96,17 @@ class Utils(object):
 			region_name=scan_info['region'])
 
 		ecr_client = session.client('ecr')
-		token = ecr_client.get_authorization_token()
-		print("ECR auth token: " + token['authorizationData'][0]['authorizationToken'])
-		ecr_username, ecr_password = base64.b64decode(token['authorizationData'][0]['authorizationToken']).decode().split(':')
-		print("ecr user: " + ecr_username)
-		print("ecr pwd: " + ecr_password)
-		registry = token['authorizationData'][0]['proxyEndpoint']
+		try:
+			token = ecr_client.get_authorization_token()
+			ecr_username, ecr_password = base64.b64decode(token['authorizationData'][0]['authorizationToken']).decode().split(':')
+			registry = token['authorizationData'][0]['proxyEndpoint']
+		except Exception as e:
+			raise DockerError('Login to docker failed while getting ECR authorization token: ' + str(e))
 
 		command = ['docker', 'login', '-u', ecr_username, '--password-stdin', registry]
 		if sys.version_info < (3, 0):
 			command = ['docker login -u ' + ecr_username + ' --password-stdin ' + registry]
 
-		print("Python version: " + str(sys.version_info.major) + "." + str(sys.version_info.minor))
-		print("docker login command: " + " ".join(command))
-
 		p = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, stdin=subprocess.PIPE, shell=True)
 		stdout, stderr = p.communicate(input=ecr_password.encode('utf-8'))
 		p.wait()
@@ -105,6 +119,7 @@ class Utils(object):
 		client = docker.from_env()
 		cls.last_time_docker_login = cls.get_timestamp()
 		"""
+		below code doesn't work even it returns 'Login succeeded', see https://github.com/docker/docker-py/issues/2256
 		client = docker.from_env()
 		try:
 			client.login(username=ecr_username, password=ecr_password, registry=registry, reauth=False)
